# eric7.EricNetwork.EricJsonStreamReader

Module implementing a JSON based reader class.

### Global Attributes

None

### Classes

EricJsonReader | Class implementing a JSON based reader class.

### Functions

None

## EricJsonReader

Class implementing a JSON based reader class.

The reader is responsible for opening a socket to listen for writer connections.

### Signals

dataReceived(object)
  emitted after a data object was received

### Derived from

QTcpServer

### Class Attributes

None

### Class Methods

None

### Methods

EricJsonReader | Constructor
__handleDisconnect | Private slot handling a disconnect of the writer.
__receiveJson | Private slot handling received data from the writer.
address | Public method to get the host address.
handleNewConnection | Public slot for new incoming connections from a writer.
port | Public method to get the port number to connect to.

### Static Methods

None

#### EricJsonReader (Constructor)

EricJsonReader(name="", interface="127.0.0.1", parent=None)

Constructor

name (str (optional))
  name of the server (used for output only) (defaults to "")
interface (str (optional))
  network interface to be used (IP address or one of "all", "allv4", "allv6", "localv4" or "localv6") (defaults to "127.0.0.1")
parent (QObject (optional))
  reference to the parent object (defaults to None)

#### EricJsonReader.__handleDisconnect

__handleDisconnect()

Private slot handling a disconnect of the writer.

#### EricJsonReader.__receiveJson

__receiveJson()

Private slot handling received data from the writer.

#### EricJsonReader.address

address()

Public method to get the host address.

Return:
  host address

Return Type:
  str

#### EricJsonReader.handleNewConnection

handleNewConnection()

Public slot for new incoming connections from a writer.

#### EricJsonReader.port

port()

Public method to get the port number to connect to.

Return:
  port number

Return Type:
  int

Up